@@ -23,24 +23,27 @@ class data_process:
             self.test_dataset = datasets.MNIST(
                 dir, train=False, download=True, transform=apply_transform)
         elif dataset_name == 'cifar10':
-            transform = transforms.Compose([transforms.ToTensor(),transforms.Normalize((0.5, 0.5, 0.5), (0.5, 0.5, 0.5))])
-            self.train_dataset = datasets.CIFAR10(root='./data/'+dataset_name, train=True,download=True, transform=transform)
-            self.test_dataset = datasets.CIFAR10(root='./data/'+dataset_name, train=False,download=True, transform=transform)
+            transform = transforms.Compose(
+                [transforms.ToTensor(), transforms.Normalize((0.5, 0.5, 0.5), (0.5, 0.5, 0.5))])
+            self.train_dataset = datasets.CIFAR10(
+                dir, train=True, download=True, transform=transform)
+            self.test_dataset = datasets.CIFAR10(
+                dir, train=False, download=True, transform=transform)
         elif dataset_name == 'femnist':
-            apply_transform = transforms.Compose([transforms.ToTensor(), transforms.Normalize((0.1307,), (0.3081,))])    
-            train_dataset = femnist.FEMNIST( './data/'+dataset_name, train=True, download=False,
-                                        transform=apply_transform)
-            test_dataset = femnist.FEMNIST( './data/'+dataset_name, train=False, download=False,
-                                       transform=apply_transform)
+            apply_transform = transforms.Compose(
+                [transforms.ToTensor(), transforms.Normalize((0.1307,), (0.3081,))])
+            train_dataset = femnist.FEMNIST(dir, train=True, download=False,
+                                            transform=apply_transform)
+            test_dataset = femnist.FEMNIST(dir, train=False, download=False,
+                                           transform=apply_transform)
         elif dataset_name == 'Fashion_Mnist':
             apply_transform = transforms.Compose([
                 transforms.ToTensor(),
                 transforms.Normalize((0.5,), (0.5,))])
             self.train_dataset = datasets.FashionMNIST(
-                './data/'+dataset_name, train=True, download=True, transform=apply_transform)
+                dir, train=True, download=True, transform=apply_transform)
             self.test_dataset = datasets.FashionMNIST(
-                './data/'+dataset_name, train=False, download=True, transform=apply_transform)
-
+                dir, train=False, download=True, transform=apply_transform)
 
         # show image
         # batch_size = 4
@@ -62,37 +65,44 @@ class data_process:
         # imshow(torchvision.utils.make_grid(images))
         # # print labels
         # print(' '.join('%5s' % classes[labels[j]] for j in range(batch_size)))
-        
 
-    def split_dataset(self, num_nodes, alpha, method = 'dirichlet'):
-        if num_nodes ==1:
-            return self.train_dataset,self.test_dataset
+    def split_dataset(self, num_nodes, alpha, method='dirichlet'):
+        if num_nodes == 1:
+            return self.train_dataset, self.test_dataset
         else:
             if method == 'iid':
-                lens_list = [int(len(dataset)/num_nodes) for i in range(num_nodes-1)]
+                lens_list = [int(len(dataset)/num_nodes)
+                             for i in range(num_nodes-1)]
                 lens_list.append(len(dataset)-sum(lens_list))
                 return random_split(dataset, lens_list)
             else:
-                self.train_dataset.targets = torch.tensor(self.train_dataset.targets)
-                self.test_dataset.targets = torch.tensor(self.test_dataset.targets)
+                self.train_dataset.targets = torch.tensor(
+                    self.train_dataset.targets)
+                self.test_dataset.targets = torch.tensor(
+                    self.test_dataset.targets)
                 labels = torch.unique(self.train_dataset.targets)
                 train_label_size = self.train_dataset.targets.bincount()
                 test_label_size = self.test_dataset.targets.bincount()
-                l_train = train_label_size.reshape(len(labels), 1).repeat(1, num_nodes)
-                l_test = test_label_size.reshape(len(labels), 1).repeat(1, num_nodes)
+                l_train = train_label_size.reshape(
+                    len(labels), 1).repeat(1, num_nodes)
+                l_test = test_label_size.reshape(
+                    len(labels), 1).repeat(1, num_nodes)
                 # print(l_test)
                 if method == 'dirichlet':
-                    p = torch.tensor(np.random.dirichlet(np.repeat(alpha, num_nodes), len(labels)))
+                    p = torch.tensor(np.random.dirichlet(
+                        np.repeat(alpha, num_nodes), len(labels)))
                 elif method == 'class':
-                    p = np.zeros((len(labels),1))
-                    J=np.random.choice(len(labels),alpha, replace=False)
-                    p[J]=1
-                    for k in range(1,num_nodes):
-                        x = np.zeros((len(labels),1))
-                        J=np.random.choice(len(labels),alpha, replace=False)
-                        x[J]=1
-                        p=np.concatenate((p,x),axis=1)
-                    p= p/np.repeat((p.sum(axis=1)+10**-10).reshape(len(labels),1),num_nodes,axis=1)
+                    p = np.zeros((len(labels), 1))
+                    J = np.random.choice(len(labels), alpha, replace=False)
+                    p[J] = 1
+                    for k in range(1, num_nodes):
+                        x = np.zeros((len(labels), 1))
+                        J = np.random.choice(len(labels), alpha, replace=False)
+                        x[J] = 1
+                        p = np.concatenate((p, x), axis=1)
+                    p = p / \
+                        np.repeat(
+                            (p.sum(axis=1)+10**-10).reshape(len(labels), 1), num_nodes, axis=1)
                 # print(p.sum(axis=1),p)
                 # p = torch.tensor(np.random.dirichlet(np.repeat(alpha,len(labels)), num_nodes)).reshape(10,100)
                 # for i in range(len(p)):
@@ -105,20 +115,25 @@ class data_process:
                 test_size = test_size.int()
                 # print(torch.sum(train_size,0),torch.sum(test_size,0))
                 # print(len((self.train_dataset.targets==0).nonzero(as_tuple=True)[0]))
-                train_splited =[]
-                test_splited =[]
+                train_splited = []
+                test_splited = []
                 train_label_index = []
                 test_label_index = []
                 for j in labels:
-                    train_label_index.append([(self.train_dataset.targets==j).nonzero(as_tuple=True)[0][offset-length:offset] for offset,length in zip(_accumulate(train_size[j,:]), train_size[j,:])])
-                    test_label_index.append([(self.test_dataset.targets==j).nonzero(as_tuple=True)[0][offset-length:offset] for offset,length in zip(_accumulate(test_size[j,:]), test_size[j,:])])
+                    train_label_index.append([(self.train_dataset.targets == j).nonzero(as_tuple=True)[
+                                             0][offset-length:offset] for offset, length in zip(_accumulate(train_size[j, :]), train_size[j, :])])
+                    test_label_index.append([(self.test_dataset.targets == j).nonzero(as_tuple=True)[
+                                            0][offset-length:offset] for offset, length in zip(_accumulate(test_size[j, :]), test_size[j, :])])
                 for i in range(num_nodes):
-                    train_splited.append(ConcatDataset([Subset(self.train_dataset,train_label_index[j][i]) for j in labels]))
-                    test_splited.append(ConcatDataset([Subset(self.test_dataset,test_label_index[j][i]) for j in labels]))
+                    train_splited.append(ConcatDataset(
+                        [Subset(self.train_dataset, train_label_index[j][i]) for j in labels]))
+                    test_splited.append(ConcatDataset(
+                        [Subset(self.test_dataset, test_label_index[j][i]) for j in labels]))
                 # print([len(train_splited[i]) for i in range(num_nodes)],[len(train_splited[i]) for i in range(num_nodes)])
                 # plot
                 for i in labels:
-                    plt.barh(range(num_nodes), train_size[i,:], left=torch.sum(train_size[:i],0),label=str(int(i)))
+                    plt.barh(range(num_nodes), train_size[i, :], left=torch.sum(
+                        train_size[:i], 0), label=str(int(i)))
                 # plt.title("Data distribution of dataset")
                 plt.legend()
                 mpl.rcParams['figure.dpi'] = 300
@@ -131,7 +146,6 @@ class data_process:
 # dt.split_dataset(10, 0.1)
 
 
-
 # def data_split(dataset, num_nodes, type='iid'):
 #     if type == 'iid':
 #         lens_list = [int(len(dataset)/num_nodes) for i in range(num_nodes-1)]
@@ -167,12 +181,12 @@ def log(file_name, nodes, server):
     log = {}
     log['node'] = {}
     for i in range(len(nodes)):
-        log['node'][str(i)]=nodes[i].accuracy
-    log['server']=server.accuracy
-    log['clustering']=server.clustering
+        log['node'][str(i)] = nodes[i].accuracy
+    log['server'] = server.accuracy
+    log['clustering'] = server.clustering
     pickle.dump(log, open(local_file, 'wb'), protocol=pickle.HIGHEST_PROTOCOL)
 
     # read
     if os.path.exists(local_file):
         log = pickle.load(open(local_file, 'rb'))
-        print(log)
\ No newline at end of file
+        print(log)
